Struct PanicException
pub struct PanicException(/* private fields */);Available on crate feature
tls only.Expand description
The exception raised when Rust code called from Python panics.
Like SystemExit, this exception is derived from BaseException so that it will typically propagate all the way through the stack and cause the Python interpreter to exit.
Implementations
impl PanicException
impl PanicException